
def checkSpecAndMeta(pac):
    ini_present = False
    ini_mod = False
    spec_mod = False

    if not pac.todo:
        pac.todo = pac.filenamelist + pac.filenamelist_unvers
    pac.todo.sort()

    for filename in pac.todo:
        if filename in pac.excluded:
            continue
        s = pac.status(filename)
        if os.path.splitext(filename)[-1] == '.ini':
            ini_present = True
            ini_mod = (s == 'M')

        if os.path.splitext(filename)[-1] == '.spec' and s == 'M':
            spec_mod = True

    if ini_present and ini_mod ^ spec_mod:
        while 1:
            input = raw_input('Warning: In moblin Package %s, ' \
                              'ONLY one from .ini and .spec file will '\
                              'be committed. Continue?\n'
                              'a)bort, c)ontinue: ' % pac.name)
            if input in 'aA':
                raise oscerr.UserAbort
            elif input in 'cC':
                break

@cmdln.alias('mci')
@cmdln.alias('mobci')
@cmdln.option('-m', '--message', metavar='TEXT',
              help='specify log message TEXT')
@cmdln.option('-F', '--file', metavar='FILE',
              help='read log message from FILE')
def do_mobcommit(self, subcmd, opts, *args):
    """${cmd_name}: Wrapper cmd for 'commit' to do extra check for moblin pac.
    All commandline options are the same as old 'commit' cmd.

    Some moblin packages use one metafile(.ini) to manage spec file. And
    the spec file should be synced with ini file. But sometime one would
    forget to update spec file after modifying metafile, or sometime one
    would modify spec file directly. In these wrong cases, there will be
    only one from metafile and spec to be committed.
    Added warning to avoid useless update.
    
    usage:
          osc mci [-m TEXT]
          osc mci [-m TEXT] SOURCEPRJ SOURCEPKG DESTPRJ [DESTPKG]
    Examples:

    ${cmd_usage}
    ${cmd_option_list}
    """

    args = parseargs(args)

    msg = ''
    if opts.message:
        msg = opts.message
    elif opts.file:
        try:
            msg = open(opts.file).read()
        except:
            sys.exit('could not open file \'%s\'.' % opts.file)

    arg_list = args[:]
    for arg in arg_list:
        if conf.config['do_package_tracking'] and is_project_dir(arg):
            Project(arg).commit(msg=msg)
            args.remove(arg)

    pacs = findpacs(args)

    """ Added code start """

    # Check sync status of .ini and .spec for moblin packages
    for pac in pacs:
        checkSpecAndMeta(pac)

    """ Added code end   """

    if not msg:
        # open editor for commit message
        # but first, produce status and diff to append to the template
        footer = diffs = []
        for pac in pacs:
            changed = getStatus([pac], quiet=True)
            if changed:
                footer += changed
                diffs += ['\nDiff for working copy: %s' % pac.dir]
                diffs += make_diff(pac, 0)
        # if footer is empty, there is nothing to commit, and no edit needed.
        if footer:
            msg = edit_message(footer='\n'.join(footer))

    if conf.config['do_package_tracking'] and len(pacs) > 0:
        prj_paths = {}
        single_paths = []
        files = {}
        # it is possible to commit packages from different projects at the same
        # time: iterate over all pacs and put each pac to the right project in the dict
        for pac in pacs:
            path = os.path.normpath(os.path.join(pac.dir, os.pardir))
            if is_project_dir(path):
                pac_path = os.path.basename(os.path.normpath(pac.absdir))
                prj_paths.setdefault(path, []).append(pac_path)
                files[pac_path] = pac.todo
            else:
                single_paths.append(pac.dir)
        for prj, packages in prj_paths.iteritems():
            Project(prj).commit(tuple(packages), msg, files)
        for pac in single_paths:
            Package(pac).commit(msg)
    else:
        for p in pacs:
            p.commit(msg)
