@cmdln.option('-n', '--nomail', action='store_true',
              help='Do not send email')
@cmdln.option('-m', '--message', metavar='TEXT',
              help='specify message TEXT')
def do_mobdecline(self, subcmd, opts, *args):
    """${cmd_name}: Decline a request to the Trunk Project.
    This special command is similar to 'osc sr decline' and will send an email to
    the submitter and the mailing list as configured in your .oscrc.
    
    You can add to configuration options to make this plugin work for you.
    1. An smtp server (By default or-out.intel.com is used)
    2. The destination mailing list (By default moblin2-commit@linux.intel.com is used)
    
    usage:
          osc mobdecline [-n] [-m TEXT] ID
    ${cmd_option_list}
    Examples:
          osc mobdecline -m 'Cannot accept request 1234' 1234
    """

    args = slash_split(args)
    min_args, max_args = 1, 1
    if len(args) < min_args:
        raise oscerr.WrongArgs('Too few arguments.')
    if len(args) > max_args:
        raise oscerr.WrongArgs('Too many arguments.')

    apiurl = conf.config['apiurl']
    reqid = args[0]

    # Query it at first, if reqid invalid, it will abort
    r = get_submit_request(apiurl, reqid)
    reqinfo = str(r)
    src_package = r.src_package
    src_project = r.src_project
    dst_package = r.dst_package
    dst_project = r.dst_project
    submitter = r.state.who

    # Check whether the state is 'new'
    if not r.state.name == 'new':
		sys.exit('This state of request %s is %s, and cannot be accepted.'
                 % (reqid, r.state.name))

    # Send the decline cmd to server
    r = change_submit_request_state(apiurl,
                                    reqid,
                                    'declined',
                                    opts.message or '')

    # Check whether the cmd succeeded
    if not r.startswith('<status code="ok" />'):
		sys.exit('Remote decline failed: %s' % r)

    print 'Request %s has been declined.' % reqid

    if opts.nomail:
		sys.exit('No email sent')

    # Prepare and send mail
    print "Preparing decline declaration email..."

    # Query info for self
    user = conf.config['user']
    meta = get_user_meta(apiurl, user)
    root = ET.fromstring(meta)
    realname = root.find('realname').text
    if not realname:
        realname = user
    email = root.find('email').text

    # Query info for submitter of request
    meta = get_user_meta(apiurl, submitter)
    root = ET.fromstring(meta)
    sub_realname = root.find('realname').text
    if not sub_realname:
        sub_realname = submitter
    sub_email = root.find('email').text
    
    commit_list = None
    if not conf.config.has_key('commit_mailing_list'):
        commit_list = "moblin2-commit@linux.intel.com"
    else:
        commit_list = conf.config['commit_mailing_list']

    RECIPIENTS = [commit_list, sub_email]
    SENDER =  email

    submission = """To: %s, %s
From: %s <%s>
Subject: %s declined: %s/%s to %s/%s

Hi %s,
The following submission has been declined. Reason:

%s

Thanks,
Moblin Release Engineering Team

[This message was auto-generated]

Request information:
---
    
%s
    
""" %(RECIPIENTS[0], RECIPIENTS[1], realname, email, reqid, src_project, src_package, dst_project, dst_package, sub_realname, opts.message or 'Not provided.', reqinfo)
   
    # self.send_email SHOULD be defined in osc-mobsr.py
   
    self.send_email( RECIPIENTS , SENDER , submission)

    pass
