@cmdln.option('-n', '--nomail', action='store_true',
              help='Do not send email')
@cmdln.option('-m', '--message', metavar='TEXT',
              help='specify message TEXT')
@cmdln.alias('mobrevoke')
def do_unmobsr(self, subcmd, opts, *args):
    """${cmd_name}: Revoke a request from the Trunk Project.
    This special command is similar to 'osc sr revoke', and will send an email
    to the mailing list as configured in your .oscrc.
    
    You can add to configuration options to make this plugin work for you.
    1. An smtp server (By default or-out.intel.com is used)
    2. The destination mailing list (By default moblin2-commit@linux.intel.com is used)
    
    Usage:
          osc unmobsr [-n] [-m TEXT] ID
    ${cmd_option_list}
    Examples:
          osc unmobsr -m 'Need revoke request 1234' 1234

    """

    args = slash_split(args)
    min_args, max_args = 1, 1
    if len(args) < min_args:
        raise oscerr.WrongArgs('Too few arguments.')
    if len(args) > max_args:
        raise oscerr.WrongArgs('Too many arguments.')

    apiurl = conf.config['apiurl']
    reqid = args[0]

    # Query it at first, if reqid invalid, it will abort
    r = get_submit_request(apiurl, reqid)
    reqinfo = str(r)
    dst_package = r.dst_package
    dst_project = r.dst_project

    # Check whether the state is 'new'
    if not r.state.name == 'new':
		sys.exit('This state of request %s is %s, and cannot be accepted.'
                 % (reqid, r.state.name))

    # Send the revoke cmd to server
    r = change_submit_request_state(apiurl, reqid, 'revoked', opts.message or '')

    # Check whether the cmd succeeded
    if not r.startswith('<status code="ok" />'):
		sys.exit('Remote revoke failed: %s' % r)

    print 'Request %s has been revoked.' % reqid

    if opts.nomail:
		sys.exit('No email sent')

    # Prepare and send mail
    print "Preparing revoke declaration email..."

    user = conf.config['user']
    meta = get_user_meta(apiurl, user)
    root = ET.fromstring(meta)
    realname = root.find('realname').text
    if not realname:
        realname = user
    email = root.find('email').text
    
    commit_list = None
    if not conf.config.has_key('commit_mailing_list'):
        commit_list = "moblin2-commit@linux.intel.com"
    else:
        commit_list = conf.config['commit_mailing_list']

    RECIPIENTS = [commit_list]
    SENDER =  email

    submission = """To: %s
From: %s <%s>
Subject: Revoked changes to %s in %s (Req: %s)

Hi,
I have revoked the change request %s to %s. Please ignore the origin request mail.
Reason:

%s

Thank You,
%s

[This message was auto-generated]

Request information:
---
    
%s
    
""" %(RECIPIENTS[0],realname, email, dst_package, dst_project, reqid, reqid, dst_package, opts.message or 'Not provided', realname, reqinfo)
   
    # self.send_email SHOULD be defined in osc-mobsr.py
   
    self.send_email( RECIPIENTS , SENDER , submission)

    pass
